summaryrefslogtreecommitdiffstats
path: root/src/gui/image/qimage_p.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/image/qimage_p.h')
-rw-r--r--src/gui/image/qimage_p.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/gui/image/qimage_p.h b/src/gui/image/qimage_p.h
index 74a79a8425..2bb989c03b 100644
--- a/src/gui/image/qimage_p.h
+++ b/src/gui/image/qimage_p.h
@@ -74,6 +74,7 @@ struct Q_GUI_EXPORT QImageData { // internal image data
int height;
int depth;
int nbytes; // number of bytes data
+ qreal devicePixelRatio;
QVector<QRgb> colortable;
uchar *data;
QImage::Format format;
@@ -81,8 +82,10 @@ struct Q_GUI_EXPORT QImageData { // internal image data
int ser_no; // serial number
int detach_no;
- qreal dpmx; // dots per meter X (or 0)
- qreal dpmy; // dots per meter Y (or 0)
+ qreal ldpmx; // logical dots per meter X (or 0)
+ qreal ldpmy; // logical dots per meter Y (or 0)
+ qreal dpmx; // device dots per meter X (or 0)
+ qreal dpmy; // device dots per meter Y (or 0)
QPoint offset; // offset in pixels
uint own_data : 1;